+++
title = 'Installing Pokemon Infinite Fusion on Linux'
date = 2025-04-16
draft = false
+++

Please check the date of this post before following, if you're reading it years into the future, it may no longer be accurate.

I would also like to mention that this is just how I've been installing/updating the game for the past 1.5 years or so. This method is not neccessarily officially supported by the Pokemon Infinite Fusion team.

## TL;DR

* Make a folder somewhere
* Run `git clone -b releases https://github.com/infinitefusion/infinitefusion-e18.git .` in it
* Launch `Game.exe` using Proton or Wine

If you're not an experienced Linux user familiar with tools like git, read on.

## Why this guide is needed

Playing Pokemon Infinite Fusion (Henceforth "PIF" or "Infinite Fusion") on Linux is actually pretty easy. Although you won't find any official information telling you just how easy it is. Rather confusingly for many users, PIF does not have an official website. The game follows the awful trend of sticking most of its info and updates into a Discord channel. However you can still find plenty of information on the game's [subreddit](https://www.reddit.com/r/PokemonInfiniteFusion/ "Link to Pokemon Infinite Fusion's official subreddit") or [wiki](https://infinitefusion.fandom.com/wiki/).

PIF does have official guides for installing on Linux (and instructions specific to the Steam Deck), but they're frankly... awful. While I don't want to discredit any work the great PIF community does, their Linux instructions really aren't optimal. It follows the "Windows-method" of downloading an extracting zip files from weird download hosts, or it wants you to juggle around some Windows launcher that's seemingly mostly just a Windows front-end for a git.exe binary. They are Windows-only install guides bodged onto Linux, rather than actual Linux install guides.

This guide exists mostly for my own use (because every time I want to install the game I forget where their git repo is) and I thought I might as well make a (somewhat) proper guide out of it. Because personally I find it much easier to update the game when it's installed using git, and others may agree.

Downloading spritepacks for offline use is NOT covered here, but should be fairly simple, download the new packs and copy them into the folder they belong in. Official guides should work for that.

## Installing on Linux

### Installing tools

You're going to need two things:

* `git` a tool used to manage code
* Steam (To run game using proton)

As of writing this, Valve's Steam Deck has git available by default, and obviously has Steam. So Steam Deck users can skip to installing the game.

Install these tools for your distro. For Debian/Ubuntu/LinuxMint this would be done by running "sudo apt install git wine" in a terminal, or by finding git and wine in your operating system's "app store". Ensure you're not installing the tools using something called "flatpak". Running PIF with flatpak-versions of the tools should work just as well, but is outside the scope of this guide.

### Installing the game

When you've got the tools installed, simply make a folder you wish to install Infinite Fusion into. Something like `/home/username/Games/Infinite Fusion` will do just fine. You then need to open this folder in a terminal. On most Linux systems (Including Steam Deck), this can be done by simply right-clicking and selecting "Open Terminal Here" or similar:

![screenshot](screenshot-open-terminal.png "Screenshot showing how to open a terminal from a folder")

We're now going to use git to download the game's files directly from its git repository. Once you have the terminal window open, ensure you're in the correct folder (The folder name will be displayed somewhere in the prompt. If it doesn't show your installation folder's name or shows `~` you are in the wrong folder, navigate to your folder and "Open Terminal Here" again) run `git clone -b releases https://github.com/infinitefusion/infinitefusion-e18.git .` inside the terminal (note the space and period at the end, those must be included). This will start the download process. As Infinite Fusion is a pretty large project with many files (even without the custom sprites) this download may take quite a while.

![screenshot](screenshot-git.png "Screenshot showing terminal output")

The command will dump you back to a prompt when done. The last line it output should say `Updating files` and end with `done.`. As long as this is the case, all game files should have been downloaded successfully.

### Launching the game

This part is fairly simple. Simply open Steam, and click "Add non-steam Game" and then hit "Browse...". Steam will ask you for a file, select `Game.exe` in the folder where you installed Infinite Fusion.

![screenshot](screenshot-non-steam.png "Screenshot showing how to add a non-steam Game")

The game should then be added to Steam as simply "Game.exe". Find this "Game.exe" entry and right click it to open its properties. Here you can fill in a name. If your folder name contains spaces, you should also ensure that "Target" and "Start in" are wrapped in double quotes:

![screenshot](screenshot-steam-prop.png "Screenshot showing steam game properties")

Last but not least, click on the "Compatibility" tab, and select a proton version to run the game with. I recommend using the latest numbered version, but feel free to try others if the game won't launch or crashes.

![screenshot](screenshot-proton.png "Screenshot showing compatibility options in Steam")

That's it, you can now launch the game via Steam and it should start without issue, assuming everything was done correctly.

You can also add game art from SteamGridDB, but I won't be covering that here, a quick google search should give you plenty of guides.

### Updating the game

Installing new updates is fairly simple. You just need to open a terminal in the game's folder (same folder where Game.exe is located) and run the following command: `git pull`. This will pull down the newest updates from the "releases" branch of the git repository.

Voila, just launch the game after doing a `git pull` and you should be on the newest version.
